@@ -1,5 +1,7 @@
 """Python library for the Wykop API."""
 from wykop.api.client import WykopAPI
+from wykop.api import api_values
+from wykop.api.api_values import PROFILE_SETTINGS
 from wykop.api.multi_key_client import MultiKeyWykopAPI
 from wykop.api.exceptions import WykopAPIError
 from wykop.utils import get_version
